@@ -1,6 +1,6 @@
 /* Simple hash table */
 
-#include "zstr.h"
+#include <string.h>
 #include "hash.h"
 
 static HENTRY *freentry=0;
@@ -55,6 +55,6 @@ char *name;
  {
  HENTRY *e;
  for(e=ht->tab[hash(name)&ht->len];e;e=e->next)
-  if(!zcmp(e->name,name)) return e->val;
+  if(!strcmp(e->name,name)) return e->val;
  return 0;
  }
