@@ -24,7 +24,7 @@ JOE; see the file COPYING.  If not, write to the Free Software Foundation,
 #include "pw.h"
 #include "qw.h"
 #include "uedit.h"
-#include "zstr.h"
+#include "utils.h"
 #include "vs.h"
 #include "ublock.h"
 
@@ -702,7 +702,7 @@ int *notify;
    else height=tmp->eof->line;
    if(bw->o.overtype)
     {
-    pclrrect(markb,Lmax(markk->line-markb->line+1,height),markk->xcol,usetabs);
+    pclrrect(markb,long_max(markk->line-markb->line+1,height),markk->xcol,usetabs);
     pdelrect(markb,height,width+markb->xcol);
     }
    pinsrect(markb,tmp,width,usetabs);
@@ -791,7 +791,7 @@ int *notify;
    if(bw->o.overtype)
     {
     pclrrect(markb,markk->line-markb->line+1,markk->xcol,usetabs);
-    pdelrect(markb,Lmax(height,markk->line-markb->line+1),width+markb->xcol);
+    pdelrect(markb,long_max(height,markk->line-markb->line+1),width+markb->xcol);
     }
    else pdelrect(markb,markk->line-markb->line+1,markk->xcol);
    pinsrect(markb,tmp,width,usetabs);
