@@ -1,12 +1,12 @@
 /* Math */
 
 #include <signal.h>
+#include <string.h>
 #include "w.h"
 #include "bw.h"
 #include "pw.h"
 #include "tw.h"
 #include "vs.h"
-#include "zstr.h"
 #include "umath.h"
 
 char *merr;
@@ -29,12 +29,12 @@ struct var *get(str)
 char *str;
  {
  struct var *v;
- for(v=vars;v;v=v->next) if(!zcmp(v->name,str)) return v;
+ for(v=vars;v;v=v->next) if(!strcmp(v->name,str)) return v;
  v=(struct var *)malloc(sizeof(struct var));
  v->set=0;
  v->next=vars;
  vars=v;
- v->name=zdup(str);
+ v->name=strdup(str);
  return v;
  }
 
@@ -157,7 +157,7 @@ int *notify;
  if(bw->parent->watom->what!=TYPETW)
   {
   binsm(bw->cursor,sz(msgbuf));
-  pfwrd(bw->cursor,zlen(msgbuf));
+  pfwrd(bw->cursor,strlen(msgbuf));
   bw->cursor->xcol=piscol(bw->cursor);
   }
  else msgnw(bw,msgbuf);
