@@ -20,20 +20,19 @@ JOE; see the file COPYING.  If not, write to the Free Software Foundation,
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <stdlib.h>
 #include "config.h"
 #include "vs.h"
-#include "zstr.h"
 #include "blocks.h"
 #include "queue.h"
 #include "path.h"
-#include "random.h"
 #include "vfile.h"
 
 static VFILE vfiles={{&vfiles,&vfiles}};	/* Known vfiles */
 static VPAGE *freepages=0;	/* Linked list of free pages */
 static VPAGE *htab[HTSIZE];	/* Hash table of page headers */
-static long curv_alloc=0;	/* Amount of memory in use */
-static long maxv_alloc= ILIMIT;	/* Maximum allowed */
+static long curvalloc=0;	/* Amount of memory in use */
+static long maxvalloc= ILIMIT;	/* Maximum allowed */
 char *vbase;			/* Data first entry in vheader refers to */
 VPAGE **vheaders=0;		/* Array of header addresses */
 static int vheadsz=0;		/* No. entries allocated to vheaders */
@@ -143,7 +142,7 @@ if(freepages)
  goto gotit;
  }
 
-if(curv_alloc+PGSIZE<=maxv_alloc)
+if(curvalloc+PGSIZE<=maxvalloc)
  {
  vp=(VPAGE *)malloc(sizeof(VPAGE)*INC);
  if(vp)
@@ -152,7 +151,7 @@ if(curv_alloc+PGSIZE<=maxv_alloc)
   if(vp->data)
    {
    int q;
-   curv_alloc+=PGSIZE*INC;
+   curvalloc+=PGSIZE*INC;
    if(!vheaders)
     vheaders=(VPAGE **)malloc((vheadsz=INC)*sizeof(VPAGE *)),
     vbase=vp->data;
@@ -311,15 +310,15 @@ long amount;
 {
 VPAGE *vp, *pp;
 int x,y;
-maxv_alloc=amount;
-while(curv_alloc>maxv_alloc)
+maxvalloc=amount;
+while(curvalloc>maxvalloc)
  if(freepages)
   {
   vp=freepages;
   freepages=vp->next;
   free(vp->data);
   free(vp);
-  curv_alloc-=PGSIZE;
+  curvalloc-=PGSIZE;
   }
  else
   {
@@ -331,7 +330,7 @@ while(curv_alloc>maxv_alloc)
      pp->next=vp->next;
      free(vp->data);
      free(vp);
-     if((curv_alloc-=PGSIZE)<=maxv_alloc) return;
+     if((curvalloc-=PGSIZE)<=maxvalloc) return;
      goto again;
      }
   vflsh();
@@ -343,7 +342,7 @@ while(curv_alloc>maxv_alloc)
      pp->next=vp->next;
      free(vp->data);
      free(vp);
-     if((curv_alloc-=PGSIZE)<=maxv_alloc) return;
+     if((curvalloc-=PGSIZE)<=maxvalloc) return;
      goto again1;
      }
   return;
@@ -351,7 +350,7 @@ while(curv_alloc>maxv_alloc)
 }
 #endif
 
-long v_alloc(vfile,size)
+long my_valloc(vfile,size)
 VFILE *vfile;
 long size;
 {
@@ -471,7 +470,7 @@ VFILE *vfile;
 long addr;
 char c;
 {
-if(addr+1>vsize(vfile)) v_alloc(vfile,addr+1-vsize(vfile));
+if(addr+1>vsize(vfile)) my_valloc(vfile,addr+1-vsize(vfile));
 if(vfile->vpage1) vunlock(vfile->vpage1);
 vfile->vpage1=vlock(vfile,vfile->addr=(addr&~(long)(PGSIZE-1)));
 return wc(vfile,addr,c);
@@ -493,7 +492,7 @@ VFILE *vfile;
 long addr;
 short c;
 {
-if(addr+2>vsize(vfile)) v_alloc(vfile,addr+2-vsize(vfile));
+if(addr+2>vsize(vfile)) my_valloc(vfile,addr+2-vsize(vfile));
 wc(vfile,addr,c);
 wc(vfile,addr+1,c>>8);
 return c;
@@ -517,7 +516,7 @@ VFILE *vfile;
 long addr;
 long c;
 {
-if(addr+4>vsize(vfile)) v_alloc(vfile,addr+4-vsize(vfile));
+if(addr+4>vsize(vfile)) my_valloc(vfile,addr+4-vsize(vfile));
 wc(vfile,addr,c);
 wc(vfile,addr+1,c>>8);
 wc(vfile,addr+2,c>>16);
@@ -561,7 +560,7 @@ int size;
 long addr=vtell(v);
 char *src;
 int x;
-if(addr+size>vsize(v)) v_alloc(v,addr+size-vsize(v));
+if(addr+size>vsize(v)) my_valloc(v,addr+size-vsize(v));
 while(size)
  {
  src=vlock(v,addr);
